@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import PrincipalTypeType, ProvisioningStatusType, ProvisionTargetTypeType
 from .paginator import (
@@ -31,28 +31,28 @@ from .paginator import (
     ListTagsForResourcePaginator,
 )
 from .type_defs import (
-    CreateAccountAssignmentResponseResponseTypeDef,
-    CreatePermissionSetResponseResponseTypeDef,
-    DeleteAccountAssignmentResponseResponseTypeDef,
-    DescribeAccountAssignmentCreationStatusResponseResponseTypeDef,
-    DescribeAccountAssignmentDeletionStatusResponseResponseTypeDef,
-    DescribeInstanceAccessControlAttributeConfigurationResponseResponseTypeDef,
-    DescribePermissionSetProvisioningStatusResponseResponseTypeDef,
-    DescribePermissionSetResponseResponseTypeDef,
-    GetInlinePolicyForPermissionSetResponseResponseTypeDef,
+    CreateAccountAssignmentResponseTypeDef,
+    CreatePermissionSetResponseTypeDef,
+    DeleteAccountAssignmentResponseTypeDef,
+    DescribeAccountAssignmentCreationStatusResponseTypeDef,
+    DescribeAccountAssignmentDeletionStatusResponseTypeDef,
+    DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef,
+    DescribePermissionSetProvisioningStatusResponseTypeDef,
+    DescribePermissionSetResponseTypeDef,
+    GetInlinePolicyForPermissionSetResponseTypeDef,
     InstanceAccessControlAttributeConfigurationTypeDef,
-    ListAccountAssignmentCreationStatusResponseResponseTypeDef,
-    ListAccountAssignmentDeletionStatusResponseResponseTypeDef,
-    ListAccountAssignmentsResponseResponseTypeDef,
-    ListAccountsForProvisionedPermissionSetResponseResponseTypeDef,
-    ListInstancesResponseResponseTypeDef,
-    ListManagedPoliciesInPermissionSetResponseResponseTypeDef,
-    ListPermissionSetProvisioningStatusResponseResponseTypeDef,
-    ListPermissionSetsProvisionedToAccountResponseResponseTypeDef,
-    ListPermissionSetsResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
+    ListAccountAssignmentCreationStatusResponseTypeDef,
+    ListAccountAssignmentDeletionStatusResponseTypeDef,
+    ListAccountAssignmentsResponseTypeDef,
+    ListAccountsForProvisionedPermissionSetResponseTypeDef,
+    ListInstancesResponseTypeDef,
+    ListManagedPoliciesInPermissionSetResponseTypeDef,
+    ListPermissionSetProvisioningStatusResponseTypeDef,
+    ListPermissionSetsProvisionedToAccountResponseTypeDef,
+    ListPermissionSetsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     OperationStatusFilterTypeDef,
-    ProvisionPermissionSetResponseResponseTypeDef,
+    ProvisionPermissionSetResponseTypeDef,
     TagTypeDef,
 )
 
@@ -84,14 +84,19 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class SSOAdminClient:
+class SSOAdminClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        SSOAdminClient exceptions.
+        """
 
     def attach_managed_policy_to_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
@@ -99,7 +104,7 @@ class SSOAdminClient:
         """
         Attaches an IAM managed policy ARN to a permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#attach_managed_policy_to_permission_set)
         """
 
@@ -107,7 +112,7 @@ class SSOAdminClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#can_paginate)
         """
 
@@ -120,12 +125,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         PrincipalType: PrincipalTypeType,
         PrincipalId: str
-    ) -> CreateAccountAssignmentResponseResponseTypeDef:
+    ) -> CreateAccountAssignmentResponseTypeDef:
         """
         Assigns access to a principal for a specified AWS account using a specified
         permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_account_assignment)
         """
 
@@ -139,7 +144,7 @@ class SSOAdminClient:
         Enables the attributes-based access control (ABAC) feature for the specified AWS
         SSO instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_instance_access_control_attribute_configuration)
         """
 
@@ -152,11 +157,11 @@ class SSOAdminClient:
         SessionDuration: str = None,
         RelayState: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreatePermissionSetResponseResponseTypeDef:
+    ) -> CreatePermissionSetResponseTypeDef:
         """
         Creates a permission set within a specified SSO instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_permission_set)
         """
 
@@ -169,12 +174,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         PrincipalType: PrincipalTypeType,
         PrincipalId: str
-    ) -> DeleteAccountAssignmentResponseResponseTypeDef:
+    ) -> DeleteAccountAssignmentResponseTypeDef:
         """
         Deletes a principal's access from a specified AWS account using a specified
         permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_account_assignment)
         """
 
@@ -184,7 +189,7 @@ class SSOAdminClient:
         """
         Deletes the inline policy from a specified permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_inline_policy_from_permission_set)
         """
 
@@ -196,7 +201,7 @@ class SSOAdminClient:
         AWS SSO instance and deletes all of the attribute mappings that have been
         configured.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_instance_access_control_attribute_configuration)
         """
 
@@ -204,59 +209,59 @@ class SSOAdminClient:
         """
         Deletes the specified permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_permission_set)
         """
 
     def describe_account_assignment_creation_status(
         self, *, InstanceArn: str, AccountAssignmentCreationRequestId: str
-    ) -> DescribeAccountAssignmentCreationStatusResponseResponseTypeDef:
+    ) -> DescribeAccountAssignmentCreationStatusResponseTypeDef:
         """
         Describes the status of the assignment creation request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_account_assignment_creation_status)
         """
 
     def describe_account_assignment_deletion_status(
         self, *, InstanceArn: str, AccountAssignmentDeletionRequestId: str
-    ) -> DescribeAccountAssignmentDeletionStatusResponseResponseTypeDef:
+    ) -> DescribeAccountAssignmentDeletionStatusResponseTypeDef:
         """
         Describes the status of the assignment deletion request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_account_assignment_deletion_status)
         """
 
     def describe_instance_access_control_attribute_configuration(
         self, *, InstanceArn: str
-    ) -> DescribeInstanceAccessControlAttributeConfigurationResponseResponseTypeDef:
+    ) -> DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef:
         """
         Returns the list of AWS SSO identity store attributes that have been configured
         to work with attributes-based access control (ABAC) for the specified AWS SSO
         instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_instance_access_control_attribute_configuration)
         """
 
     def describe_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str
-    ) -> DescribePermissionSetResponseResponseTypeDef:
+    ) -> DescribePermissionSetResponseTypeDef:
         """
         Gets the details of the permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_permission_set)
         """
 
     def describe_permission_set_provisioning_status(
         self, *, InstanceArn: str, ProvisionPermissionSetRequestId: str
-    ) -> DescribePermissionSetProvisioningStatusResponseResponseTypeDef:
+    ) -> DescribePermissionSetProvisioningStatusResponseTypeDef:
         """
         Describes the status for the given permission set provisioning request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_permission_set_provisioning_status)
         """
 
@@ -266,7 +271,7 @@ class SSOAdminClient:
         """
         Detaches the attached IAM managed policy ARN from the specified permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#detach_managed_policy_from_permission_set)
         """
 
@@ -280,17 +285,17 @@ class SSOAdminClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#generate_presigned_url)
         """
 
     def get_inline_policy_for_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str
-    ) -> GetInlinePolicyForPermissionSetResponseResponseTypeDef:
+    ) -> GetInlinePolicyForPermissionSetResponseTypeDef:
         """
         Obtains the inline policy assigned to the permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#get_inline_policy_for_permission_set)
         """
 
@@ -301,12 +306,12 @@ class SSOAdminClient:
         MaxResults: int = None,
         NextToken: str = None,
         Filter: "OperationStatusFilterTypeDef" = None
-    ) -> ListAccountAssignmentCreationStatusResponseResponseTypeDef:
+    ) -> ListAccountAssignmentCreationStatusResponseTypeDef:
         """
         Lists the status of the AWS account assignment creation requests for a specified
         SSO instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignment_creation_status)
         """
 
@@ -317,12 +322,12 @@ class SSOAdminClient:
         MaxResults: int = None,
         NextToken: str = None,
         Filter: "OperationStatusFilterTypeDef" = None
-    ) -> ListAccountAssignmentDeletionStatusResponseResponseTypeDef:
+    ) -> ListAccountAssignmentDeletionStatusResponseTypeDef:
         """
         Lists the status of the AWS account assignment deletion requests for a specified
         SSO instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignment_deletion_status)
         """
 
@@ -334,12 +339,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListAccountAssignmentsResponseResponseTypeDef:
+    ) -> ListAccountAssignmentsResponseTypeDef:
         """
         Lists the assignee of the specified AWS account with the specified permission
         set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignments)
         """
 
@@ -351,21 +356,21 @@ class SSOAdminClient:
         ProvisioningStatus: ProvisioningStatusType = None,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListAccountsForProvisionedPermissionSetResponseResponseTypeDef:
+    ) -> ListAccountsForProvisionedPermissionSetResponseTypeDef:
         """
         Lists all the AWS accounts where the specified permission set is provisioned.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_accounts_for_provisioned_permission_set)
         """
 
     def list_instances(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListInstancesResponseResponseTypeDef:
+    ) -> ListInstancesResponseTypeDef:
         """
         Lists the SSO instances that the caller has access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_instances)
         """
 
@@ -376,11 +381,11 @@ class SSOAdminClient:
         PermissionSetArn: str,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListManagedPoliciesInPermissionSetResponseResponseTypeDef:
+    ) -> ListManagedPoliciesInPermissionSetResponseTypeDef:
         """
         Lists the IAM managed policy that is attached to a specified permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_managed_policies_in_permission_set)
         """
 
@@ -391,22 +396,22 @@ class SSOAdminClient:
         MaxResults: int = None,
         NextToken: str = None,
         Filter: "OperationStatusFilterTypeDef" = None
-    ) -> ListPermissionSetProvisioningStatusResponseResponseTypeDef:
+    ) -> ListPermissionSetProvisioningStatusResponseTypeDef:
         """
         Lists the status of the permission set provisioning requests for a specified SSO
         instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_set_provisioning_status)
         """
 
     def list_permission_sets(
         self, *, InstanceArn: str, NextToken: str = None, MaxResults: int = None
-    ) -> ListPermissionSetsResponseResponseTypeDef:
+    ) -> ListPermissionSetsResponseTypeDef:
         """
         Lists the  PermissionSet s in an SSO instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_sets)
         """
 
@@ -418,21 +423,21 @@ class SSOAdminClient:
         ProvisioningStatus: ProvisioningStatusType = None,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListPermissionSetsProvisionedToAccountResponseResponseTypeDef:
+    ) -> ListPermissionSetsProvisionedToAccountResponseTypeDef:
         """
         Lists all the permission sets that are provisioned to a specified AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_sets_provisioned_to_account)
         """
 
     def list_tags_for_resource(
         self, *, InstanceArn: str, ResourceArn: str, NextToken: str = None
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    ) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags that are attached to a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_tags_for_resource)
         """
 
@@ -443,12 +448,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         TargetType: ProvisionTargetTypeType,
         TargetId: str = None
-    ) -> ProvisionPermissionSetResponseResponseTypeDef:
+    ) -> ProvisionPermissionSetResponseTypeDef:
         """
         The process by which a specified permission set is provisioned to the specified
         target.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#provision_permission_set)
         """
 
@@ -458,7 +463,7 @@ class SSOAdminClient:
         """
         Attaches an IAM inline policy to a permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#put_inline_policy_to_permission_set)
         """
 
@@ -468,7 +473,7 @@ class SSOAdminClient:
         """
         Associates a set of tags with a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#tag_resource)
         """
 
@@ -478,7 +483,7 @@ class SSOAdminClient:
         """
         Disassociates a set of tags from a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#untag_resource)
         """
 
@@ -492,7 +497,7 @@ class SSOAdminClient:
         Updates the AWS SSO identity store attributes to use with the AWS SSO instance
         for attributes-based access control (ABAC).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#update_instance_access_control_attribute_configuration)
         """
 
@@ -508,7 +513,7 @@ class SSOAdminClient:
         """
         Updates an existing permission set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#update_permission_set)
         """
 
@@ -517,7 +522,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignment_creation_status"]
     ) -> ListAccountAssignmentCreationStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
         """
 
@@ -526,7 +531,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignment_deletion_status"]
     ) -> ListAccountAssignmentDeletionStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
         """
 
@@ -535,7 +540,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignments"]
     ) -> ListAccountAssignmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
         """
 
@@ -544,14 +549,14 @@ class SSOAdminClient:
         self, operation_name: Literal["list_accounts_for_provisioned_permission_set"]
     ) -> ListAccountsForProvisionedPermissionSetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_instances"]) -> ListInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
         """
 
@@ -560,7 +565,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_managed_policies_in_permission_set"]
     ) -> ListManagedPoliciesInPermissionSetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
         """
 
@@ -569,7 +574,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_set_provisioning_status"]
     ) -> ListPermissionSetProvisioningStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
         """
 
@@ -578,7 +583,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_sets"]
     ) -> ListPermissionSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
         """
 
@@ -587,7 +592,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_sets_provisioned_to_account"]
     ) -> ListPermissionSetsProvisionedToAccountPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
         """
 
@@ -596,6 +601,6 @@ class SSOAdminClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
         """
